==> haskell-async-2.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.0
id: async-2.1.0-IGx6TJY2BPOHCk3x4WAuIK
key: async-2.1.0-IGx6TJY2BPOHCk3x4WAuIK
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
abi: 24c595b90add1dc3c61ee3e7a993f14e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/async-2.1.0
hs-libraries: HSasync-2.1.0-IGx6TJY2BPOHCk3x4WAuIK
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-async-2.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1
id: async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
key: async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
abi: fe6a941879eb9aa215ad18a6974e8492
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/async-2.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/async-2.1.1
hs-libraries: HSasync-2.1.1-9CmNvQft9hOA1w6AR7WdJM
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
